==> trilinos_9.0.3.dfsg.orig.tar.gz: trilinos-9.0.3.dfsg.orig/packages/Sundance/src-solvers/Testing/TSFPoissonBoltzmannOp.hpp <==
/* @HEADER@ */
/* ***********************************************************************
// 
//           TSFExtended: Trilinos Solver Framework Extended
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// **********************************************************************/
/* @HEADER@ */

#ifndef TSF_POISSONBOLTZMANNOP_HPP
#define TSF_POISSONBOLTZMANNOP_HPP

#include "TSFConfigDefs.hpp"
#include "TSFNonlinearOperatorBase.hpp"
#include "TSFPoissonBoltzmannJacobian.hpp"
#include "TSFVector.hpp"

namespace TSFExtended
{
  /** */
  class PoissonBoltzmannOp : public NonlinearOperatorBase<double>
  {
  public:
    /** */
    PoissonBoltzmannOp(int nLocal, const VectorType<double>& vecType);

    /** */
    Vector<double> getInitialGuess() const ;

    /** */
    Vector<double> exactSoln() const ;

    

    /* */
    GET_RCP(NonlinearOperatorBase<double>);

  protected:
    /** */
    LinearOperator<double> 
    computeJacobianAndFunction(Vector<double>& functionValue) const ;

  private:

    mutable PoissonBoltzmannJacobian J_;
    
    RefCountPtr<GhostImporter<double> > importer_;

    double uLeftBC_;

    double uRightBC_;

    
  };
 
}


#endif

==> trilinos_10.4.0.dfsg.orig.tar.gz: trilinos-10.4.0.dfsg.orig/packages/Sundance/src-solvers/Testing/TSFPoissonBoltzmannOp.hpp <==
/* @HEADER@ */
/* ***********************************************************************
// 
//           TSFExtended: Trilinos Solver Framework Extended
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// **********************************************************************/
/* @HEADER@ */

#ifndef TSF_POISSONBOLTZMANNOP_HPP
#define TSF_POISSONBOLTZMANNOP_HPP

#include "SundanceDefs.hpp"
#include "TSFNonlinearOperatorBase.hpp"
#include "TSFPoissonBoltzmannJacobian.hpp"
#include "TSFVectorDecl.hpp"

namespace TSFExtended
{
  /** */
  class PoissonBoltzmannOp : public NonlinearOperatorBase<double>
  {
  public:
    /** */
    PoissonBoltzmannOp(int nLocal, const VectorType<double>& vecType);

    /** */
    Vector<double> getInitialGuess() const ;

    /** */
    Vector<double> exactSoln() const ;

    

    /* */
    GET_RCP(NonlinearOperatorBase<double>);

  protected:
    /** */
    LinearOperator<double> 
    computeJacobianAndFunction(Vector<double>& functionValue) const ;

  private:

    mutable PoissonBoltzmannJacobian J_;
    
    RCP<GhostImporter<double> > importer_;

    double uLeftBC_;

    double uRightBC_;

    
  };
 
}


#endif
